/*
    Author: Andy Kirby, Email: andy@kirbyand.co.uk, Date: 13/06/2013
    Contributors: 
    Licensing GPL V3 (http://www.gnu.org/licenses/quick-guide-gplv3.html).

    Script to create a 241Americium illuminator ring for XRF and Scintilator testing.
    Based on original ideas from GEO & The Yahoo Gamma Spec Group work on the RapCap.
    The illuminator sits on top of the test subject (dish/slide/sample) and a detector
    (LEG Probe for XRF or PMT for Scint testing) sits on top of the illuminator.
    Design is scripted for 6 241Am buttons of aprox 33KBq each.

    The design assumes the mean free path of the 241Am alpha particles is 25mm in air.

    Thanks to Dr John Mcmillan,(j.e.mcmillan@sheffield.ac.uk) 
    Department of Physics & Astronomy,
    University of Sheffield
*/

/* Global Variables */
// Parameters to change the part, all dims in mm
odillum = 50;    	// OD of illuminator
wallthick = 3;		// Thickness of illuminator wall at thinest part
detstandoff = 10;  // Height of the standoff to the detector
substandoff = 5;  	// height of the standoff to the subject
hfring = 7.5;       // height of the focus ring, also reduction in fring radius to get 45 deg
smooth = 64;		// smoothness of the circle, how many facets a circle is made from
odamdisk = 6.5;		// OD of the americium button disk
odampimp = 3.5;		// OD of the americium button pimple on the back of the disk
hamdisk = 1.7;		// Height of the americium disk
hampimp = 1.7;		// Height of the americium pimple on the back of the disk

// Do not change, precalculated factors to aid layout.
odfring = odillum - (2 * wallthick);
rfring = odfring / 2;
hillum = detstandoff + substandoff + hfring;
rillum = odillum / 2;
rwindow = rfring - hfring;
ramdisk = odamdisk / 2;
rampimp = hampimp / 2;
amxdisp = rwindow + (hfring / 2);




/* Main or start function basicaly do it */
render (convexity = 1) {
   AM241Illum();
}


/*
   module to create the coupler as the difference between solids describing the parts
*/
module AM241Illum()
{
   translate([0,0,hillum]) mirror([ 0, 0, 1 ]) {
      difference(){   
         illumbody();
         detwindow();
         fring();
         substand();
      }
   }
}


/*
   module to create the solid illuminator body
*/ 
module illumbody() {
   cylinder(h=hillum, r1=rillum, r2=rillum, center=false, $fn = smooth);
}


/*
   module to create a cutout for the detector window
*/
module detwindow() {
   cylinder(h=hillum, r1=rwindow, r2=rwindow, center=false, $fn = smooth);
}


/*
   module to create the cutout for the focus ring including illuminator sockets
*/
module fring() {
   translate([0,0,substandoff]) {
      union(){
         cylinder(h=hfring, r1=rfring, r2=rwindow, center=false, $fn = smooth);
         rotate(a=[0,0,0]) translate([0,-amxdisp,0]) 241ambutton();
         rotate(a=[0,0,60]) translate([0,-amxdisp,0]) 241ambutton();
         rotate(a=[0,0,120]) translate([0,-amxdisp,0]) 241ambutton();
         rotate(a=[0,0,180]) translate([0,-amxdisp,0]) 241ambutton();
         rotate(a=[0,0,240]) translate([0,-amxdisp,0]) 241ambutton();
         rotate(a=[0,0,300]) translate([0,-amxdisp,0]) 241ambutton();
      }
   }
}


/*
   module to create the spacer or standoff to the subject being illuminated
*/
module substand() {
         cylinder(h=substandoff, r1=rfring, r2=rfring, center=false, $fn = smooth);
}


/*
   module to create a solid aproximation of the 241Am button
   note the module angles the 241AM button to match focus ring angle
*/
module 241ambutton(){
   translate([0,0,ramdisk]) rotate(a=[45,0,0]){
      union(){
         cylinder(h=hampimp + hamdisk, r1=rampimp, r2=rampimp, center=false, $fn = smooth);
         cylinder(h=hamdisk, r1=ramdisk, r2=ramdisk, center=false, $fn = smooth);
      }
   }
}










   